#ifndef CCOLOR
#define CCOLOR

//-----------------------------------------------------------------------------
class CColor
{
//-----------------------------------------------------------------------------
  int r;
  int g;
  int b;

//-----------------------------------------------------------------------------
public:

  CColor() 
  : r( 0 ), g( 0 ), b( 0 )
  {}

  CColor( const int r, const int g, const int b )
  : r( r ), g( g ), b( b )
  {};

  CColor( const QRgb& qrgb )
  : r( ( qrgb >> 16 ) & 0x000000FF ),
    g( ( qrgb >> 8 ) & 0x000000FF ),
    b( qrgb & 0x000000FF )
  {};

  CColor( const CColor& col )
  : r( col.red() ), g( col.green() ), b( col.blue() )
  {};

  const int red() const { return r; };

  const int green() const { return g; };

  const int blue() const { return b; };

  const QRgb qRgb() const {
    return 0xFF000000 + ( r << 16 ) + ( g << 8 ) + b;
  };

  CColor operator * ( const CColor& other ) const 
  {
    return CColor( ( r * other.red() + 0.5 ) / 255,
                   ( g * other.green() + 0.5 ) / 255,
                   ( b * other.blue() + 0.5 ) / 255 );
  };

  CColor operator * ( const double w ) const  {
    return CColor( r*w + 0.5, g*w + 0.5, b*w + 0.5 );
  };

  friend CColor operator * ( const double w, const CColor& color ) {
    return color * w;
  }

  const CColor& operator += ( const CColor& other )
  {
    r += other.red();
    g += other.green();
    b += other.blue();
    return *this;
  }

  const CColor operator + ( const CColor& other ) const
  {
    return CColor( r + other.red(), 
      g + other.green(), b + other.blue() );
  }

  const CColor& normalize() 
  {
    r = std::max( 0, std::min( 255, r ) );
    g = std::max( 0, std::min( 255, g ) );
    b = std::max( 0, std::min( 255, b ) );

    return *this;
  }

};

#endif